##  Report-specific configuration
Further configuration of reports is possible in the Reports Settings menu and is report-specific. Common configurations include clustering Fact Sheets based on a specific type, setting timeline parameters to visualize data within a specific time frame, selecting different parameters for the X and Y axes, and choosing left and right properties to display on Fact Sheet items in the report.
**Note**
Only single select fields can be used for clustering in reports.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a4bcb7a441014925aae0a4732262c_LowRes.png)
Adjacent to the Settings, there are additional choices for structuring reports effectively. You can customize the order of appearance through Sorting, specify the hierarchy level for information display with the Level option, and switch the Layout Mode of the Report between Stacked, Detailed, or Rolled-Up modes according to your requirements.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752dbed7a441014a7e9f86215bce502_LowRes.png)
